import { Plugin } from "@webiny/plugins";
import { FieldSortOptions, SortOrder } from "elastic-ts";
export type UnmappedTypes = "date" | "long" | string;
export interface ToSearchValueParams {
    /**
     * The value to transform.
     */
    value: any;
    /**
     * When using toSearchValue() in our code we send a field.getPath() value here.
     */
    path: string;
    /**
     * When using toSearchValue() in our code we send a field.getBasePath() value here.
     */
    basePath: string;
}
export interface ElasticsearchFieldPluginParams {
    /**
     * Which field is this plugin for.
     */
    field: string;
    /**
     * Some specific path of a field?
     * Example: createdBy is createdBy.id
     */
    path?: string;
    /**
     * Add a .keyword at the end of the field path?
     */
    keyword?: boolean;
    /**
     * Is the field of a specific type, but possibly not mapped?
     * Happens when inserting a date in string format.
     * You need to cast it as date when running the search/sort to work correctly.
     */
    unmappedType?: UnmappedTypes;
    /**
     * Is the field sortable?
     */
    sortable?: boolean;
    /**
     * Is the field searchable?
     */
    searchable?: boolean;
    /**
     * Used to transform the input value for the search.
     */
    toSearchValue?: (params: ToSearchValueParams) => any;
}
export declare class ElasticsearchFieldPlugin extends Plugin {
    static readonly type: string;
    static readonly ALL: string;
    readonly field: string;
    readonly path: string;
    readonly keyword: boolean;
    readonly unmappedType?: string;
    readonly sortable: boolean;
    readonly searchable: boolean;
    constructor(params: ElasticsearchFieldPluginParams);
    /**
     * The default sort options. Extend in your own plugin if you want to add more options.
     */
    getSortOptions(order: SortOrder): FieldSortOptions;
    /**
     * The default path generator. Extend in your own plugin if you want to add more options.
     * Field parameter is here because there is a possibility that this is the ALL field plugin, so we need to know which field are we working on.
     */
    getPath(field: string): string;
    /**
     * @see getPath
     *
     * This is the default base path generator. Basically it replaces ALL with given field name.
     */
    getBasePath(field: string): string;
    /**
     * The default transformer. Just returns the value by default.
     * Override to implement what ever is required.
     */
    toSearchValue(params: ToSearchValueParams): any;
}
